aboutsummaryrefslogtreecommitdiff
path: root/kernel
diff options
context:
space:
mode:
Diffstat (limited to 'kernel')
-rw-r--r--kernel/cpuset.c18
1 files changed, 8 insertions, 10 deletions
diff --git a/kernel/cpuset.c b/kernel/cpuset.c
index ab0be4565..f3a417c1d 100644
--- a/kernel/cpuset.c
+++ b/kernel/cpuset.c
@@ -2601,28 +2601,26 @@ int cpuset_mems_allowed_intersects(const struct task_struct *tsk1,
#define CPUSET_NODELIST_LEN (256)
/**
* cpuset_print_task_mems_allowed - prints task's cpuset and mems_allowed
* @task: pointer to task_struct of some task.
*
* Description: Prints @task's name, cpuset name, and cached copy of its
* mems_allowed to the kernel log. Must hold task_lock(task) to allow
* dereferencing task_cs(task).
*/
-void cpuset_print_task_mems_allowed(struct task_struct *tsk)
+void cpuset_print_current_mems_allowed(void)
{
/* Statically allocated to prevent using excess stack. */
static char cpuset_nodelist[CPUSET_NODELIST_LEN];
static DEFINE_SPINLOCK(cpuset_buffer_lock);
- struct cgroup *cgrp = task_cs(tsk)->css.cgroup;
+ struct cgroup *cgrp = task_cs(current)->css.cgroup;
rcu_read_lock();
spin_lock(&cpuset_buffer_lock);
nodelist_scnprintf(cpuset_nodelist, CPUSET_NODELIST_LEN,
- tsk->mems_allowed);
- printk(KERN_INFO "%s cpuset=%s mems_allowed=%s\n",
- tsk->comm, cgroup_name(cgrp), cpuset_nodelist);
+ current->mems_allowed);
+ pr_info("%s cpuset=%s mems_allowed=%s\n",
+ current->comm, cgroup_name(cgrp), cpuset_nodelist);
spin_unlock(&cpuset_buffer_lock);
rcu_read_unlock();
@@ -2601,28 +2601,26 @@ int cpuset_mems_allowed_intersects(const struct task_struct *tsk1,
#define CPUSET_NODELIST_LEN (256)
/**
- * cpuset_print_task_mems_allowed - prints task's cpuset and mems_allowed
- * @task: pointer to task_struct of some task.
+ * cpuset_print_current_mems_allowed - prints current's cpuset and mems_allowed
*
@@ -2601,28 +2601,26 @@ int cpuset_mems_allowed_intersects(const struct task_struct *tsk1,
*
- * Description: Prints @task's name, cpuset name, and cached copy of its
- * mems_allowed to the kernel log. Must hold task_lock(task) to allow
- * dereferencing task_cs(task).
+ * Description: Prints current's name, cpuset name, and cached copy of its
+ * mems_allowed to the kernel log.
*/